@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "auto-dark" "0.13.9"
+(define-package "auto-dark" "20251006.358"
   "Automatically set the dark-mode theme based on system status."
   '((emacs "24.4"))
   :url "https://github.com/LionyxML/auto-dark-emacs"
-  :commit "280d9a6e6ab0ccb833185761734585344ce22095"
-  :revdesc "280d9a6e6ab0"
+  :commit "a71e791e47d09c5bf4bcbc2bbd7300b71ff72f1a"
+  :revdesc "a71e791e47d0"
   :keywords '("macos" "windows" "linux" "themes" "tools" "faces")
   :authors '(("Tim Harper" . "timcharperatgmaildotcom")
              ("Vincent Zhang" . "seagle0128@gmail.com")
