@@ -6,8 +6,8 @@
 ;;         Jonathan Arnett <jonathan.arnett@protonmail.com>
 ;;         Greg Pfeil <greg@technomadic.org>
 ;; Created: July 16 2019
-;; Package-Version: 0.13.9
-;; Package-Revision: 280d9a6e6ab0
+;; Package-Version: 20251006.358
+;; Package-Revision: a71e791e47d0
 ;; Keywords: macos, windows, linux, themes, tools, faces
 ;; URL: https://github.com/LionyxML/auto-dark-emacs
 ;; Package-Requires: ((emacs "24.4"))
@@ -273,7 +273,6 @@ time."
 (defvar auto-dark--timer nil)
 (defun auto-dark-start-timer ()
   "Start auto-dark timer."
-  (auto-dark-stop-timer)
   (setq auto-dark--timer
         (run-with-timer 0
                         auto-dark-polling-interval-seconds
@@ -371,8 +370,7 @@ Remove theme change callback registered with D-Bus."
          auto-dark-allow-powershell)
     'powershell)
    ((and (eq system-type 'gnu/linux)
-         (string-match "-[Mm]icrosoft"
-                       (string-trim (shell-command-to-string "uname -r")))
+         (string-match "-[Mm]icrosoft" operating-system-release)
          auto-dark-allow-powershell)
     'powershell)
    ((eq system-type 'windows-nt)
